@@ -1,16 +1,13 @@
 use anyhow::Result;
 use serde::{Deserialize, Serialize};
-use serde_json::{self, json};
 use std::{
     env,
     fmt::Display,
     fs::{self, create_dir, read_dir, read_to_string},
 };
 
-use crate::{
-    model::Model,
-    utils::{fs::create_file, swc},
-};
+use crate::model::Model;
+use crate::utils::styles::compile_styles;
 
 #[derive(Clone, Debug, PartialEq)]
 pub struct Version(u8, u8, u8);
@@ -130,7 +127,7 @@ impl Project {
         // Create model files
         for model in &self.models {
             let path = format!("{}/models/{}.json", self.name, model.name);
-            create_file(&path, json!(model))?;
+            fs::write(&path, serde_json::to_string(model).unwrap())?;
         }
 
         // Copy static files
@@ -140,27 +137,25 @@ impl Project {
         )?;
 
         // Compile styles
-        if let Ok(styles) =
-            grass::from_path("template/styles/main.scss", &grass::Options::default())
-        {
-            let path = format!("{}/public/main.css", self.name);
-            create_file(&path, styles)?;
-        }
+        let css = compile_styles()?;
+        fs::write(format!("{}/public/main.css", self.name), css)?;
 
         // Compile scripts
-        if let Ok(js) = swc::compile_ts("template/scripts/app.ts") {
-            let path = format!("{}/public/scripts/app.js", self.name);
-            create_file(&path, js)?;
-        }
+        // if let Ok(js) = swc::compile_ts("template/scripts/app.ts") {
+        //     let path = format!("{}/public/scripts/app.js", self.name);
+        //     create_file(&path, js)?;
+        // }
 
         // Misc
-        create_file(
-            &format!("{}/.env", self.name),
+        fs::write(
+            format!("{}/.env", self.name),
             format!("DATABASE_URI={}", self.db_uri),
         )?;
-        create_file(&format!("{}/.gitignore", self.name), ".env")?;
-        create_file(
-            &format!("{}/mezzo.json", self.name),
+
+        fs::write(format!("{}/.gitignore", self.name), ".env")?;
+
+        fs::write(
+            format!("{}/mezzo.json", self.name),
             serde_json::to_string(self).unwrap(),
         )?;
 
