@@ -10,6 +10,10 @@ pub struct Parts;
 #[folder = "template/pages/"]
 pub struct Pages;
 
+#[derive(RustEmbed)]
+#[folder = "template/styles"]
+pub struct Styles;
+
 fn json_helper(
     h: &Helper,
     _: &Handlebars,
